import { DeclarationOption } from 'typedoc';
/**
 *
 * TypeDoc creates documentation according to exports. The structure will be driven by the implemented entryPoints config. https://typedoc.org/guides/options/#entrypointstrategy.
 *
 * This options aims to provide some flexibility as to how files can be generated.
 *
 * **`--outputFileStrategy members`**
 *
 * Generates an individual file for each exported member. This is the standard behaviour of the HTML theme and the plugin default.
 *
 * In this example output folder structure modules `module-a` and `module-b` export two classes and variables each:
 *
 * ```
 * ├── README.md
 * ├── API.md
 * ├── module-a
 * ├── ├── README.md
 * │   ├── classes
 * │   │   ├── ClassA.md
 * │   │   ├── ClassB.md
 * ├── ├── variables
 * │   │   ├── VariableA.md
 * │   │   ├── VariableB.md
 * ├── module-b
 * ├── ├── README.md
 * │   ├── classes
 * │   │   ├── ClassA.md
 * │   │   ├── ClassB.md
 * ├── ├── variables
 * │   │   ├── VariableA.md
 * │   │   ├── VariableB.md
 * ```
 *
 * When `members` is set, it is also possible to further refine what members are exported to individual files with the [`membersWithOwnFile`](#membersWithOwnFile) option.
 *
 * **`--outputFileStrategy modules`**
 *
 * Generates a single file for every Module or Namespace where all members are hoisted to a single module file. This creates a flat navigation structure and reduces the amount of files generated.
 *
 * The above example will output the following folder structure:
 *
 * ```
 * ├── README.md
 * ├── API.md
 * ├── module-a.md
 * ├── module-b.md
 * ```
 *
 * @category fileOutput
 */
export declare const mdOutputFileStrategy: DeclarationOption;
/**
 * To export only Interfaces, classes and enums to their own file, the option should be configured in an options file as follows:
 *
 * ```js
 * {
 *   membersWithOwnFile: ['Interface', 'Class', 'Enum']
 * }
 * ```
 *
 * @category fileOutput
 */
export declare const membersWithOwnFile: DeclarationOption;
/**
 * The entry page in this context is the reference to the file that acts as a root page for a project and it's folders, equivalent to `index.html` for web pages.
 *
 * `README.md` is recognised when browsing folders on repos and Wikis. `index.md` might be better if published as a web site.
 *
 * The content of this file at the root of the project is conditional on if a readme file is resolved for the project.
 *
 * A. If a readme file is resolved then two root files are generated:
 *
 * ```
 * ├── README.md - (the project readme file)
 * ├── API.md - (API index page)
 * ```
 *
 * B. If a readme file is NOT resolved (when `readme` = `none`), then the index page becomes the `entryFileName` page and there is no seperate index page.
 *
 * ```
 * ├── README.md - (API index page)
 * ```
 *
 * @category fileOutput
 *
 */
export declare const entryFileName: DeclarationOption;
/**
 * @category ui
 */
export declare const hidePageHeader: DeclarationOption;
/**
 * @category ui
 */
export declare const hidePageTitle: DeclarationOption;
/**
 * @category ui
 */
export declare const hideBreadcrumbs: DeclarationOption;
/**
 * @category ui
 */
export declare const hideInPageTOC: DeclarationOption;
/**
 * This provides a mechanism to change the main project index page title.
 *
 * Note this will also serve as the root breadcrumb text.
 *
 * @category ui
 */
export declare const indexPageTitle: DeclarationOption;
/**
 * Supports {kind} and {name} placeholders.
 *
 * Example for displaying name only:
 *
 * ```
 * titleTemplate: "{name}"
 * ```
 *
 * Example for displaying kind in backticks:
 *
 * ```
 * titleTemplate: "{name} `{kind}`"
 * ```
 *
 * @category ui
 */
export declare const titleTemplate: DeclarationOption;
/**
 * By default members are grouped by kind (eg Classes, Functions etc).
 *
 * This creates a flat structure where all members are displayed at the same level.
 *
 * **With groups**
 *
 * ```markdown
 * # SomeModule
 *
 * ## Classes
 *
 * ### ClassA
 *
 * ## Functions
 *
 * ### FunctionA
 *```
 *
 * **Without groups**
 *
 * ```markdown
 * # SomeModule
 *
 * ## ClassA
 *
 * ## FunctionA
 * ```
 *
 * @category ui
 */
export declare const excludeGroups: DeclarationOption;
/**
 * This option can be used to improve readability and aesthetics when defining signatures and declarations.
 *
 * *Default example:*
 *
 * > **basicFunction**(someParam): `string`
 *
 * *Example inside code block:*
 *
 * ```ts
 * basicFunction(someParam): string
 * ```
 *
 * Note when this option is set to `true` it is not possible to link to other references.
 *
 * As a work around the {\@link} tag can be be used to manually reference types.
 *
 * @category ui
 */
export declare const useCodeBlocks: DeclarationOption;
/**
 * By default objects inside declaration are collapsed to preserve space and improve readability.
 *
 * *Default example:*
 *
 * `object`
 *
 * *Expanded example:*
 *
 * { `x`: `string` }
 *
 * @category ui
 */
export declare const expandObjects: DeclarationOption;
/**
 * @category ui
 */
export declare const parametersFormat: DeclarationOption;
/**
 * @category ui
 */
export declare const propertiesFormat: DeclarationOption;
/**
 * @category ui
 */
export declare const enumMembersFormat: DeclarationOption;
/**
 * @category ui
 */
export declare const typeDeclarationFormat: DeclarationOption;
/**
 * @category ui
 */
export declare const indexFormat: DeclarationOption;
/**
 */
export declare const preserveAnchorCasing: DeclarationOption;
/**
 */
export declare const anchorPrefix: DeclarationOption;
/**
 * Internal anchor links are used when referencing symbols with in-page table of contents or when referenced with  by {\@link} tags.
 *
 * There are two flags exposed by this option:
 *
 * - `headings` - Add HTML named anchors to heading for implementations that do not assign header ids.
 * - `tableRows` - Add anchors to table rows when table formats are selected and no heading elements are present.
 */
export declare const namedAnchors: DeclarationOption;
