"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.namedAnchors = exports.anchorPrefix = exports.preserveAnchorCasing = exports.indexFormat = exports.typeDeclarationFormat = exports.enumMembersFormat = exports.propertiesFormat = exports.parametersFormat = exports.expandObjects = exports.useCodeBlocks = exports.excludeGroups = exports.titleTemplate = exports.indexPageTitle = exports.hideInPageTOC = exports.hideBreadcrumbs = exports.hidePageTitle = exports.hidePageHeader = exports.entryFileName = exports.membersWithOwnFile = exports.mdOutputFileStrategy = void 0;
const typedoc_1 = require("typedoc");
const custom_maps_1 = require("./custom-maps");
/**
 *
 * TypeDoc creates documentation according to exports. The structure will be driven by the implemented entryPoints config. https://typedoc.org/guides/options/#entrypointstrategy.
 *
 * This options aims to provide some flexibility as to how files can be generated.
 *
 * **`--outputFileStrategy members`**
 *
 * Generates an individual file for each exported member. This is the standard behaviour of the HTML theme and the plugin default.
 *
 * In this example output folder structure modules `module-a` and `module-b` export two classes and variables each:
 *
 * ```
 * ├── README.md
 * ├── API.md
 * ├── module-a
 * ├── ├── README.md
 * │   ├── classes
 * │   │   ├── ClassA.md
 * │   │   ├── ClassB.md
 * ├── ├── variables
 * │   │   ├── VariableA.md
 * │   │   ├── VariableB.md
 * ├── module-b
 * ├── ├── README.md
 * │   ├── classes
 * │   │   ├── ClassA.md
 * │   │   ├── ClassB.md
 * ├── ├── variables
 * │   │   ├── VariableA.md
 * │   │   ├── VariableB.md
 * ```
 *
 * When `members` is set, it is also possible to further refine what members are exported to individual files with the [`membersWithOwnFile`](#membersWithOwnFile) option.
 *
 * **`--outputFileStrategy modules`**
 *
 * Generates a single file for every Module or Namespace where all members are hoisted to a single module file. This creates a flat navigation structure and reduces the amount of files generated.
 *
 * The above example will output the following folder structure:
 *
 * ```
 * ├── README.md
 * ├── API.md
 * ├── module-a.md
 * ├── module-b.md
 * ```
 *
 * @category fileOutput
 */
exports.mdOutputFileStrategy = {
    name: 'outputFileStrategy',
    help: 'Determines how output files are generated.',
    type: typedoc_1.ParameterType.Map,
    map: custom_maps_1.OutputFileStrategy,
    defaultValue: custom_maps_1.OutputFileStrategy.Members,
};
/**
 * To export only Interfaces, classes and enums to their own file, the option should be configured in an options file as follows:
 *
 * ```js
 * {
 *   membersWithOwnFile: ['Interface', 'Class', 'Enum']
 * }
 * ```
 *
 * @category fileOutput
 */
exports.membersWithOwnFile = {
    name: 'membersWithOwnFile',
    help: 'Determines which members are exported to their own file. Ignored when `outputFileStrategy` = `modules`.',
    type: typedoc_1.ParameterType.Array,
    validate(values) {
        const validValues = custom_maps_1.MembersWithOwnFile;
        for (const kind of values) {
            if (!validValues.includes(kind)) {
                throw new Error(`'${kind}' is an invalid value for 'membersWithOwnFile'. Must be one of: ${validValues.join(', ')}`);
            }
        }
    },
    defaultValue: custom_maps_1.MembersWithOwnFile,
};
/**
 * The entry page in this context is the reference to the file that acts as a root page for a project and it's folders, equivalent to `index.html` for web pages.
 *
 * `README.md` is recognised when browsing folders on repos and Wikis. `index.md` might be better if published as a web site.
 *
 * The content of this file at the root of the project is conditional on if a readme file is resolved for the project.
 *
 * A. If a readme file is resolved then two root files are generated:
 *
 * ```
 * ├── README.md - (the project readme file)
 * ├── API.md - (API index page)
 * ```
 *
 * B. If a readme file is NOT resolved (when `readme` = `none`), then the index page becomes the `entryFileName` page and there is no seperate index page.
 *
 * ```
 * ├── README.md - (API index page)
 * ```
 *
 * @category fileOutput
 *
 */
exports.entryFileName = {
    name: 'entryFileName',
    help: 'The file name of the entry page.',
    type: typedoc_1.ParameterType.String,
    defaultValue: 'README.md',
};
/**
 * @category ui
 */
exports.hidePageHeader = {
    name: 'hidePageHeader',
    help: 'Do not print page header.',
    type: typedoc_1.ParameterType.Boolean,
    defaultValue: false,
};
/**
 * @category ui
 */
exports.hidePageTitle = {
    name: 'hidePageTitle',
    help: 'Do not print page title.',
    type: typedoc_1.ParameterType.Boolean,
    defaultValue: false,
};
/**
 * @category ui
 */
exports.hideBreadcrumbs = {
    name: 'hideBreadcrumbs',
    help: 'Do not print breadcrumbs.',
    type: typedoc_1.ParameterType.Boolean,
    defaultValue: false,
};
/**
 * @category ui
 */
exports.hideInPageTOC = {
    name: 'hideInPageTOC',
    help: 'Do not render in-page TOC/Index items.',
    type: typedoc_1.ParameterType.Boolean,
    defaultValue: false,
};
/**
 * This provides a mechanism to change the main project index page title.
 *
 * Note this will also serve as the root breadcrumb text.
 *
 * @category ui
 */
exports.indexPageTitle = {
    name: 'indexPageTitle',
    help: 'The title of project index page.',
    type: typedoc_1.ParameterType.String,
    defaultValue: '{projectName}',
};
/**
 * Supports {kind} and {name} placeholders.
 *
 * Example for displaying name only:
 *
 * ```
 * titleTemplate: "{name}"
 * ```
 *
 * Example for displaying kind in backticks:
 *
 * ```
 * titleTemplate: "{name} `{kind}`"
 * ```
 *
 * @category ui
 */
exports.titleTemplate = {
    name: 'titleTemplate',
    help: 'Specify a template for displaying page titles.',
    type: typedoc_1.ParameterType.String,
    defaultValue: '{kind}: {name}',
};
/**
 * By default members are grouped by kind (eg Classes, Functions etc).
 *
 * This creates a flat structure where all members are displayed at the same level.
 *
 * **With groups**
 *
 * ```markdown
 * # SomeModule
 *
 * ## Classes
 *
 * ### ClassA
 *
 * ## Functions
 *
 * ### FunctionA
 *```
 *
 * **Without groups**
 *
 * ```markdown
 * # SomeModule
 *
 * ## ClassA
 *
 * ## FunctionA
 * ```
 *
 * @category ui
 */
exports.excludeGroups = {
    name: 'excludeGroups',
    help: 'Excludes grouping by reflection kind so all members are rendered and sorted at the same level.',
    type: typedoc_1.ParameterType.Boolean,
    defaultValue: false,
};
/**
 * This option can be used to improve readability and aesthetics when defining signatures and declarations.
 *
 * *Default example:*
 *
 * > **basicFunction**(someParam): `string`
 *
 * *Example inside code block:*
 *
 * ```ts
 * basicFunction(someParam): string
 * ```
 *
 * Note when this option is set to `true` it is not possible to link to other references.
 *
 * As a work around the {\@link} tag can be be used to manually reference types.
 *
 * @category ui
 */
exports.useCodeBlocks = {
    name: 'useCodeBlocks',
    help: 'Format signatures and declarations in code blocks.',
    type: typedoc_1.ParameterType.Boolean,
    defaultValue: false,
};
/**
 * By default objects inside declaration are collapsed to preserve space and improve readability.
 *
 * *Default example:*
 *
 * `object`
 *
 * *Expanded example:*
 *
 * { `x`: `string` }
 *
 * @category ui
 */
exports.expandObjects = {
    name: 'expandObjects',
    help: 'Expand objects inside declarations.',
    type: typedoc_1.ParameterType.Boolean,
    defaultValue: false,
};
/**
 * @category ui
 */
exports.parametersFormat = {
    name: 'parametersFormat',
    help: 'Specify the render style of parameter and type parameter groups.',
    type: typedoc_1.ParameterType.Map,
    map: custom_maps_1.FormatStyle,
    defaultValue: custom_maps_1.FormatStyle.List,
};
/**
 * @category ui
 */
exports.propertiesFormat = {
    name: 'propertiesFormat',
    help: 'Specify the render style of properties groups for interfaces and classes.',
    type: typedoc_1.ParameterType.Map,
    map: custom_maps_1.FormatStyle,
    defaultValue: custom_maps_1.FormatStyle.List,
};
/**
 * @category ui
 */
exports.enumMembersFormat = {
    name: 'enumMembersFormat',
    help: 'Specify the render style of Enum members.',
    type: typedoc_1.ParameterType.Map,
    map: custom_maps_1.FormatStyle,
    defaultValue: custom_maps_1.FormatStyle.List,
};
/**
 * @category ui
 */
exports.typeDeclarationFormat = {
    name: 'typeDeclarationFormat',
    help: 'Specify the render style for type declaration members.',
    type: typedoc_1.ParameterType.Map,
    map: custom_maps_1.FormatStyle,
    defaultValue: custom_maps_1.FormatStyle.List,
};
/**
 * @category ui
 */
exports.indexFormat = {
    name: 'indexFormat',
    help: 'Render indexes either as a simple list or a table with a description.',
    type: typedoc_1.ParameterType.Map,
    map: custom_maps_1.FormatStyle,
    defaultValue: custom_maps_1.FormatStyle.List,
};
/**
 */
exports.preserveAnchorCasing = {
    name: 'preserveAnchorCasing',
    help: 'Preserve anchor casing when generating links.',
    type: typedoc_1.ParameterType.Boolean,
    defaultValue: false,
};
/**
 */
exports.anchorPrefix = {
    name: 'anchorPrefix',
    help: 'Custom anchor prefix',
    type: typedoc_1.ParameterType.String,
    defaultValue: undefined,
};
/**
 * Internal anchor links are used when referencing symbols with in-page table of contents or when referenced with  by {\@link} tags.
 *
 * There are two flags exposed by this option:
 *
 * - `headings` - Add HTML named anchors to heading for implementations that do not assign header ids.
 * - `tableRows` - Add anchors to table rows when table formats are selected and no heading elements are present.
 */
exports.namedAnchors = {
    name: 'namedAnchors',
    help: 'Use HTML named anchor tags for internal anchor links.',
    type: typedoc_1.ParameterType.Flags,
    defaults: {
        headings: false,
        tableRows: false,
    },
};
